@@ -4,11 +4,14 @@ from show.models import Show
 
 register = template.Library()
 
-@register.inclusion_tag('show/inclusion_tags/radioshow_entryitem_listing.html', takes_context=True)
+
+@register.inclusion_tag('show/inclusion_tags/radioshow_entryitem_\
+        listing.html', takes_context=True)
 def radioshow_entryitem_listing(context, object_list):
     context.update({'object_list': object_list})
     return context
 
+
 @register.inclusion_tag('show/inclusion_tags/showcontributor_header.html')
 def showcontributor_header(obj):
     from cal.models import Entry
@@ -22,6 +25,7 @@ def showcontributor_header(obj):
         'object': obj
     }
 
+
 @register.inclusion_tag('show/inclusion_tags/showcontributor_detail.html')
 def showcontributor_detail(obj):
     return {'object': obj}
